#    Copyright (c) 2013 Mirantis, Inc.
#
#    Licensed under the Apache License, Version 2.0 (the "License"); you may
#    not use this file except in compliance with the License. You may obtain
#    a copy of the License at
#
#         http://www.apache.org/licenses/LICENSE-2.0
#
#    Unless required by applicable law or agreed to in writing, software
#    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#    License for the specific language governing permissions and limitations
#    under the License.

# List of data types should corresponds to sections in manifest files

MANIFEST = 'manifests'
UI = 'ui'
WORKFLOW = 'workflows'
HEAT = 'heat'
AGENT = 'agent'
SCRIPTS = 'scripts'

DATA_TYPES = [UI, WORKFLOW, HEAT, AGENT, SCRIPTS, MANIFEST]
CLIENTS_DICT = {'conductor': (WORKFLOW, HEAT, AGENT, SCRIPTS),
                'ui': (UI,)}

ARCHIVE_PKG_NAME = 'data.tar.gz'

UI_FIELDS_IN_MANIFEST = {'description': 'description',
                         'type': 'full_service_name',
                         'name': 'service_display_name'}

SERVICE_DEFINITIONS_FOLDER_NAME = 'service_definitions'
CACHE_FOLDER_NAME = 'cache'
